// Sample dataset
const dataset = [
  {
    date: '3/20/2020 8:47',
    patient_id: '145-39-5406',
    patient_gender: 'M',
    patient_age: 69,
    patient_sat_score: 10,
    patient_first_inital: 'H',
    patient_last_name: 'Glasspool',
    patient_race: 'White',
    patient_admin_flag: 'FALSE',
    patient_waittime: 39,
    department_referral: 'None',
  },
  // Add more data objects as needed
];

// Convert the dataset into a hierarchical structure
const hierarchicalData = {
  name: 'Patients',
  children: dataset.map((patient) => ({
    name: `${patient.patient_first_inital}. ${patient.patient_last_name}`,
    value: patient.patient_age,
    children: [
      { name: `ID: ${patient.patient_id}`, value: null },
      {
        name: `Gender: ${patient.patient_gender}`,
        value: null,
      },
      { name: `Age: ${patient.patient_age}`, value: null },
      // Add more attributes as needed
    ],
  })),
};

// Define width, height, and margin of the tree
const margin = {
  top: 10,
  right: 250,
  bottom: 10,
  left: 100,
};
const width = 800 - margin.left - margin.right;
const height = 600 - margin.top - margin.bottom;

// Create a tree layout and assign size
const treeLayout = d3.tree().size([height, width]);

// Create a root node
const rootNode = d3.hierarchy(hierarchicalData);

// Compute the layout
treeLayout(rootNode);

// Append an SVG element to the body
const svg = d3
  .select('body')
  .append('svg')
  .attr('width', width + margin.left + margin.right)
  .attr('height', height + margin.top + margin.bottom)
  .append('g')
  .attr(
    'transform',
    `translate(${margin.left},${margin.top})`,
  );

// Create links between nodes
svg
  .selectAll('.link')
  .data(rootNode.links())
  .enter()
  .append('path')
  .attr('class', 'link')
  .attr(
    'd',
    d3
      .linkHorizontal()
      .x((d) => d.y)
      .y((d) => d.x),
  );

// Create nodes
const node = svg
  .selectAll('.node')
  .data(rootNode.descendants())
  .enter()
  .append('g')
  .attr('class', 'node')
  .attr('transform', (d) => `translate(${d.y},${d.x})`);

// Append circles to nodes
node.append('circle').attr('r', 5);

// Append text to nodes
node
  .append('text')
  .attr('dy', '0.35em')
  .attr('x', (d) => (d.children ? -10 : 10))
  .style('text-anchor', (d) =>
    d.children ? 'end' : 'start',
  )
  .text((d) => d.data.name);
